%define debug_package %{nil}
%define py_setup        setup.py

Summary:	Tools for the extraction of digital artifacts from volatile memory (RAM) images

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		Volatility
Version:	2.6.1
Release:	5%{?dist}

License:	GPL

Group:		Applications/Forensics Tools
URL:		https://github.com/volatilityfoundation/volatility

Source0:	volatility-%{version}.tar.gz
Patch1:		volatility-%{version}-patch-001
Patch2:		volatility-%{version}-patch-002
Patch3:		volatility-%{version}-patch-003
Patch4:		volatility-%{version}-patch-004

BuildRoot:	%{buildroot}
BuildRequires:	python2
%if 0%{?centos} == 7
BuildRequires:	python-pillow
%endif
%if 0%{?centos} == 6
BuildRequires:	python-imaging
%endif
%if 0%{?fedora}
BuildRequires:	python2-imaging
%endif
BuildRequires:	python2-yara
Requires:	python2-yara
%if 0%{?centos} == 6
BuildRequires:  python-crypto
Requires:       python-crypto
%else
BuildRequires:  python2-crypto
Requires:       python2-crypto
%endif
BuildRequires:	python2-distorm3 
Requires:	python2-distorm3
BuildRequires:	python2-construct
Requires:	python2-construct
%if 0%{?fedora} == 32
Obsoletes:	Volatility == 2.6.1-3
%endif


%description
The Volatility Framework is a completely open collection of tools,
implemented in Python under the GNU General Public License, for the
extraction of digital artifacts from volatile memory (RAM) images. The
extraction techniques are performed completely independent of the system
being investigated but offer unprecedented visibilty into the runtime
state of the system. The framework is intended to introduce people to the
techniques and complexities associated with extracting digital artifacts
from volatile memory images and provide a platform for further work into
this exciting area of research.

The Volatility Framework demonstrates our committment to and belief
in the importance of open source digital investigation tools. Volatile
Systems is committed to the belief that the technical procedures used to
extract digital evidence should be open to peer analysis and review. We
also believe this is in the best interest of the digital investigation
community, as it helps increase the communal knowledge about systems we
are forced to investigate. Similarly, we do not believe the availability
of these tools should be restricted and therefore encourage people to
modify, extend, and make derivative works, as permitted by the GPL.

%prep
%setup -n volatility-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
%py2_build

%install
%{__rm} -rf %{buildroot}
python2 setup.py install --root="%{buildroot}" --prefix="%{_prefix}" --no-compile
%__install -d %{buildroot}/%{_bindir}
%__install -m 755 vol.py %{buildroot}/%{_bindir}
ln -s vol.py %{buildroot}/%{_bindir}/vol
ln -s vol.py %{buildroot}/%{_bindir}/volatility
python2 vol.py -h
%__install -m 644 v*.py*  %{buildroot}%{python2_sitelib}

################################################################################################################
# Fix the Shebang problem for Python2 executables
################################################################################################################
for s in %{buildroot}%{_bindir}/* %{buildroot}%{_prefix}/tools/*.py %{buildroot}%{_prefix}/tools/mac/*.py
do
	file $s | grep -q -i 'python script' && sed --in-place '1s=python[^2]*=python2=' $s
done

%clean
# %{__rm} -rf %{buildroot}

%files
%defattr(444, bin, bin, 0755)
%doc AUTHORS.txt CHANGELOG.txt CREDITS.txt LICENSE.txt MANIFEST.in README.txt LEGAL.txt PKG-INFO
%attr(555, bin, bin)	%{_bindir}/vol.py*
%{_bindir}/vol
%{_bindir}/volatility
%attr(444, bin, bin)	%{python2_sitelib}/vol*.py*
%attr(444, bin, bin)	%{python2_sitelib}/volatility/*.py*
%attr(444, bin, bin)	%{python2_sitelib}/volatility/*/*.py*
%attr(444, bin, bin)	%{python2_sitelib}/volatility/*/*/*.py*
%attr(444, bin, bin)	%{python2_sitelib}/volatility/*/*/*/*.py*
%dir			%{python2_sitelib}/volatility
%attr(444, bin, bin) 	%{python2_sitelib}/volatility-%{version}*.egg-info
%dir			%{python2_sitelib}/volatility/plugins
%dir			%{python2_sitelib}/volatility/plugins/addrspaces
%dir			%{python2_sitelib}/volatility/plugins/registry
%dir			%{python2_sitelib}/volatility/plugins/overlays
%dir			%{python2_sitelib}/volatility/plugins/overlays/windows
%dir			%{python2_sitelib}/volatility/win32
%attr(444, bin, bin)	/usr/contrib/*.py*
%attr(444, bin, bin)	/usr/contrib/plugins/*.py*
%attr(444, bin, bin)	/usr/contrib/library_example/*.py*
%attr(444, bin, bin)	/usr/contrib/plugins/aspaces
%attr(444, bin, bin)	/usr/contrib/plugins/malware
%attr(444, bin, bin)	/usr/tools/linux/Makefile*
%attr(444, bin, bin)	/usr/tools/linux/*.c
%attr(444, bin, bin)	/usr/tools/linux/kcore/*
%attr(755, bin, bin)	/usr/tools/mac/*.py*
%attr(755, bin, bin)	/usr/tools/windows/*.py*
%attr(755, bin, bin)	/usr/tools/*.py*
%attr(644, bin, bin)	/usr/tools/doxygen/config
%attr(444, bin, bin)	/usr/tools/doxygen/d3/createtree.py*
%attr(444, bin, bin)	/usr/tools/doxygen/d3/tree.html
%attr(444, bin, bin)	/usr/tools/doxygen/vol.png

%changelog
* Tue Oct 27 2020 Lawrence R. Rogers <lrr@cert.org> 2.6.1-5
* Release 2.6.1-5
	Version 2.6.1 patched to 2020107

* Mon Jun  8 2020 Lawrence R. Rogers <lrr@cert.org> 2.6.1-4
* Release 2.6.1-4
	Version 2.6.1 patched to 20200608

* Mon Jul 29 2019 Lawrence R. Rogers <lrr@cert.org> 2.6.1-3
* Release 2.6.1-3
	Version 2.6.1 patched to 20190729

* Wed Apr  3 2019 Lawrence R. Rogers <lrr@cert.org> 2.6.1-2
* Release 2.6.1-2
	Version 2.6.1 patched to 20190403

* Wed Apr  3 2019 Lawrence R. Rogers <lrr@cert.org> 2.6.1-1
* Release 2.6.1-1
	Version 2.6.1 from December 18, 2018

* Mon Apr  1 2019 Lawrence R. Rogers <lrr@cert.org> 2.6-7
* Release 2.6-7
	Version 2.6 patched to 20190401

* Wed Jan 16 2019 Lawrence R. Rogers <lrr@cert.org> 2.6-6
* Release 2.6-6
	Version 2.6 patched to 20190116

* Mon Nov 19 2018 Lawrence R. Rogers <lrr@cert.org> 2.6-5
* Release 2.6-5
	Version 2.6 patched to 20181119

* Mon Oct 15 2018 Lawrence R. Rogers <lrr@cert.org> 2.6-4
* Release 2.6-4
	Version 2.6 patched to 20181015

* Fri Jun 15 2018 Lawrence R. Rogers <lrr@cert.org> 2.6-3
* Release 2.6-3
	Version 2.6 patched to 20180615

* Tue Jan  2 2018 Lawrence R. Rogers <lrr@cert.org> 2.6-2
* Release 2.6-2
	Version 2.6 patched to 20180102

* Tue Dec 27 2016 Lawrence R. Rogers <lrr@cert.org> 2.6-1
* Release 2.6-1
	Version 2.6

* Fri Jul  8 2016 Lawrence R. Rogers <lrr@cert.org> 2.5-4
* Release 2.5-4
	Patch to bring current to 2016-07-08.

* Wed Nov 18 2015 Lawrence R. Rogers <lrr@cert.org> 2.5-3
* Release 2.5-3
	Rebuilt with an older version of distorm3 to address a specific error.

* Tue Oct 20 2015 Lawrence R. Rogers <lrr@cert.org> 2.5-2
* Release 2.5-2
	This is the official Volatility 2.5 release.
	See the announcement here: http://www.volatilityfoundation.org/#!25/c1f29.

* Tue Oct 20 2015 Lawrence R. Rogers <lrr@cert.org> 2.5-1
* Release 2.5-1
	Version 2.5.

* Tue Jun 30 2015 Lawrence R. Rogers <lrr@cert.org> 2.4-9
* Release 2.4-9
	See https://code.google.com/p/volatility/source/list for a list of changes

* Fri Mar 27 2015 Lawrence R. Rogers <lrr@cert.org> 2.4-8
* Release 2.4-8
	Added the mimikatz.py plugin from 2014-03-25.

* Mon Mar 23 2015 Lawrence R. Rogers <lrr@cert.org> 2.4-7
* Release 2.4-7
	See https://code.google.com/p/volatility/source/list for a list of changes

* Mon Feb  9 2015 Lawrence R. Rogers <lrr@cert.org> 2.4-6
* Release 2.4-6
	See https://code.google.com/p/volatility/source/list for a list of changes
	Added version 2.4 cheat sheet

* Mon Nov  3 2014 Lawrence R. Rogers <lrr@cert.org> 2.4-5
* Release 2.4-5
	See https://code.google.com/p/volatility/source/list for a list of changes

* Mon Nov  3 2014 Lawrence R. Rogers <lrr@cert.org> 2.4-4
* Release 2.4-4
	See https://code.google.com/p/volatility/source/list for a list of changes

* Thu Oct  9 2014 Lawrence R. Rogers <lrr@cert.org> 2.4-3
* Release 2.4-3
	See https://code.google.com/p/volatility/source/list for a list of changes

* Tue Sep 23 2014 Lawrence R. Rogers <lrr@cert.org> 2.4-2
* Release 2.4-2
	See https://code.google.com/p/volatility/source/list for a list of changes

* Thu Aug 14 2014 Lawrence R. Rogers <lrr@cert.org> 2.4-1
* Release 2.4-1
	See https://code.google.com/p/volatility/source/list for a list of changes

* Mon Jan 20 2014 Lawrence R. Rogers <lrr@cert.org> 2.3.1-2
* Release 2.3.1-2
	Rebuild for yara-2.0.0.

* Wed Oct 30 2013 Lawrence R. Rogers <lrr@cert.org> 2.3.1-1
* Release 2.3.1-1
	See https://code.google.com/p/volatility/source/list for a list of changes

* Wed Oct 30 2013 Lawrence R. Rogers <lrr@cert.org> 2.3-1
* Release 2.3-1
	See https://code.google.com/p/volatility/source/list for a list of changes

* Mon Oct 1 2012 Lawrence R. Rogers <lrr@cert.org> 2.2-1
* Release 2.2-1
	See https://code.google.com/p/volatility/source/list for a list of changes

* Sat Jan 7 2012 Lawrence R. Rogers <lrr@cert.org> 2.0.1-3
* Release 2.0.1-3
	Added revision R134 of malware.py from the Malware Cookbook (http://www.malwarecookbook.com/)
	It includes the following:
		r134	remove CheckPoolIndex on IoFs pool scanner
		r133 	add --physical-offset option to psxview. Fixes Issue #37
		r131 	compat change for timers plugin on 2.0 and 2.1
		r127 	malware.py compatibility changes to allow easy integration to vol 2.0 and vol 2.1 alpha
		r126 	revert changes to malware.py r124 - incompatible with vol2.0
		r124 	update malware plugins with changes made to main branch in Issue 1137 (http://code.google.com/p/volatility/source/detail?r=1137)
		r112 	fix hex formatting issue in timers plugin
		r111 	add timers plugin 

* Tue Aug 23 2011 Lawrence R. Rogers <lrr@cert.org> 2.0.1-2
* Release 2.0.1-2
	Added malware.py from the Malware Cookbook (http://www.malwarecookbook.com/)

* Tue Aug 2 2011 Lawrence R. Rogers <lrr@cert.org> 2.0-2
* Release 2.0-2
	Path to python incorrectly specified for RHEL

* Mon Aug 1 2011 Lawrence R. Rogers <lrr@cert.org> 2.0-1
* Release 2.0-1
	New version
	See https://code.google.com/p/volatility/updates/list for changes

* Thu Jun 9 2011 Lawrence R. Rogers <lrr@cert.org> 1.4python_rc1-1
* Release 1.4_rc1-1
	New version
